@@ -28,7 +28,7 @@ setup(
       'sio_tools',
       'pandas'
     ],
-    packages=['cytolysis'],
-    package_dir={'cytolysis': 'src'},
-    package_data={'cytolysis': ['examples/*.txt','examples/*.cym']},
+    packages=['cytolysis','cytolysis.examples'],
+    package_dir={'cytolysis': 'src', 'cytolysis.examples': 'examples'},
+    package_data={'cytolysis.examples': ['examples/*.txt', 'examples/*.cym']},
  )
